@@ -3,8 +3,6 @@ use Mouse;
 use CPANPLUS::Backend;
 use Path::Class qw(file dir);
 use URI;
-use File::Basename;
-use CPAN::DistnameInfo;
 with 'CPAN::Packager::Role::Logger';
 with 'CPAN::Packager::Downloader::Role';
 
@@ -45,20 +43,9 @@ sub download {
     };
 
     return () unless $archive;
+    $self->log( info => "Downloaded $module" );
 
-    my $basename  = fileparse($archive);
-    my $distro    = CPAN::DistnameInfo->new($basename);
-    my $dist_name = $distro->dist;
-    my $version   = $distro->version;
-
-    $dist_name =~ s/-/::/g;
-    $self->log( info => "Downloaded $module ! dist is $dist_name " );
-    return {
-        tgz_path  => $archive,
-        src_dir   => $where,
-        version   => $version,
-        dist_name => $dist_name
-    };
+    return $self->analyze_distname_info($archive, $where);
 }
 
 no Mouse;
